package com.jsowell.pile.service;

import com.jsowell.pile.domain.PileLicenceInfo;

import java.util.List;

/**
 * 充电桩证书信息Service接口
 * 
 * @author jsowell
 * @date 2022-08-27
 */
public interface IPileLicenceInfoService 
{
    /**
     * 查询充电桩证书信息
     * 
     * @param id 充电桩证书信息主键
     * @return 充电桩证书信息
     */
    public PileLicenceInfo selectPileLicenceInfoById(Long id);

    /**
     * 查询充电桩证书信息列表
     * 
     * @param pileLicenceInfo 充电桩证书信息
     * @return 充电桩证书信息集合
     */
    public List<PileLicenceInfo> selectPileLicenceInfoList(PileLicenceInfo pileLicenceInfo);

    /**
     * 新增充电桩证书信息
     * 
     * @param pileLicenceInfo 充电桩证书信息
     * @return 结果
     */
    public int insertPileLicenceInfo(PileLicenceInfo pileLicenceInfo);

    /**
     * 修改充电桩证书信息
     * 
     * @param pileLicenceInfo 充电桩证书信息
     * @return 结果
     */
    public int updatePileLicenceInfo(PileLicenceInfo pileLicenceInfo);

    /**
     * 批量删除充电桩证书信息
     * 
     * @param ids 需要删除的充电桩证书信息主键集合
     * @return 结果
     */
    public int deletePileLicenceInfoByIds(Long[] ids);

    /**
     * 删除充电桩证书信息信息
     * 
     * @param id 充电桩证书信息主键
     * @return 结果
     */
    public int deletePileLicenceInfoById(Long id);
}
